# Changelog

## 0.2.0

- Added formula inputs in amount fields!

## 0.1.16

- Updated bar visuals for non-rounded variation
- WIP Budgets
- WIP Tests

## 0.1.15

- Fix: Deleted categories visible

## 0.1.14

- Fix: Lock textual version and defer upgrade to future

## 0.1.13

- Fix: Income record split value should be subtracted, not added, to the account balance

## 0.1.12

- Added total amount in persons view
- Fix: Transfers not using active date

## 0.1.11

- Add transfers as templates.
- Fix: Crash when go to date in calendar
- Fix: Not creating and using custom config file

## 0.1.10

- View by accounts is now an app action. Records will be filtered as well in that view.
- Fix: Not using active filter date when creating a paid split
- Fix: Crash when entering scientific notation / negative numbers in the amount field
- Fix: New record modal having extra width due to hidden fields
